import { Controller, Get, Query } from '@nestjs/common'
import { ApiOperation, ApiTags } from '@nestjs/swagger'

import { ListUsersDto, RunPromptDto } from '@/dto/agent-server'

import { AgentServerService } from './service/agent-server.service'

@ApiTags('agent-server')
@Controller('agent-server')
export class AgentServerController {
  constructor(private readonly agentServerService: AgentServerService) {}

  @Get('staffs')
  @ApiOperation({ summary: '获取客服列表' })
  async listStaffs() {
    return this.agentServerService.listStaffs()
  }

  @Get('staff/profile')
  @ApiOperation({ summary: '获取客服信息' })
  async getStaffProfile(@Query('staff_id') staff_id: string) {
    return this.agentServerService.getStaffProfile(staff_id)
  }

  @Get('user/profile')
  @ApiOperation({ summary: '获取用户信息' })
  async getUserProfile(@Query('user_id') user_id: string) {
    return this.agentServerService.getUserProfile(user_id)
  }

  @Get('users')
  @ApiOperation({ summary: '获取用户列表' })
  async listUsers(@Query() query: ListUsersDto) {
    return this.agentServerService.listUsers(
      query.user_name,
      query.user_union_id
    )
  }

  @Get('dialogue/history')
  @ApiOperation({ summary: '获取对话历史' })
  async getDialogueHistory(
    @Query('staff_id') staff_id: string,
    @Query('user_id') user_id: string,
    @Query('recent_minutes') recent_minutes: string
  ) {
    return this.agentServerService.getDialogueHistory(
      staff_id,
      user_id,
      recent_minutes
    )
  }

  @Get('models')
  @ApiOperation({ summary: '获取模型列表' })
  async listModels() {
    return this.agentServerService.listModels()
  }

  @Get('scenes')
  @ApiOperation({ summary: '获取场景列表' })
  async listScenes() {
    return this.agentServerService.listScenes()
  }

  @Get('base-prompt')
  @ApiOperation({ summary: '获取基础提示词' })
  async getBasePrompt() {
    return this.agentServerService.getBasePrompt()
  }

  @Get('run-prompt')
  @ApiOperation({ summary: '运行提示词' })
  async runPrompt(@Query() query: RunPromptDto) {
    return this.agentServerService.runPrompt(query)
  }
}
