import { HttpService } from '@nestjs/axios'
import { Injectable } from '@nestjs/common'
import { lastValueFrom } from 'rxjs'

import { IAgentServerService } from '@/interface/agent-server.interface'
import { ServiceResponse } from '@/response/response.interface'
import { HttpStatusCode } from '@/response/status-code.enum'

@Injectable()
export class AgentServerHttpService implements IAgentServerService {
  private readonly baseUrl = 'http://192.168.206.189:8083/api'

  constructor(private readonly httpService: HttpService) {}

  private async makeRequest<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    try {
      const url = `${this.baseUrl}/${endpoint}`
      const responseObservable = await this.httpService.get<ServiceResponse<T>>(
        url,
        { params }
      )
      const { data } = await lastValueFrom(responseObservable)
      return data
    } catch (error) {
      return {
        code: HttpStatusCode.INTERNAL_SERVER_ERROR,
        msg: error.message,
        data: null as T
      }
    }
  }

  async listStaffs(): Promise<ServiceResponse<StaffsType[]>> {
    return this.makeRequest<StaffsType[]>('listStaffs')
  }

  async getStaffProfile(
    staff_id: string
  ): Promise<ServiceResponse<StaffProfile>> {
    return this.makeRequest<StaffProfile>('getStaffProfile', { staff_id })
  }

  async getUserProfile(user_id: string): Promise<ServiceResponse<UserProfile>> {
    return this.makeRequest<UserProfile>('getUserProfile', { user_id })
  }

  async listUsers(
    user_name: string,
    user_union_id: string
  ): Promise<ServiceResponse<UserProfile[]>> {
    return this.makeRequest<UserProfile[]>('listUsers', {
      user_name,
      user_union_id
    })
  }

  async getDialogueHistory(
    staff_id: string,
    user_id: string,
    recent_minutes: string
  ): Promise<ServiceResponse<DialogueHistory[]>> {
    return this.makeRequest<DialogueHistory[]>('getDialogueHistory', {
      staff_id,
      user_id,
      recent_minutes
    })
  }

  async listModels(): Promise<ServiceResponse<Model[]>> {
    return this.makeRequest<Model[]>('listModels')
  }

  async listScenes(): Promise<ServiceResponse<any[]>> {
    return this.makeRequest<any[]>('listScenes')
  }

  async getBasePrompt(): Promise<ServiceResponse<string>> {
    return this.makeRequest<string>('getBasePrompt')
  }

  async runPrompt(prompt: any): Promise<ServiceResponse<any>> {
    return this.makeRequest<any>('runPrompt', prompt)
  }
}
