import { Inject, Injectable } from '@nestjs/common'

import { IAgentServerService } from '@/interface/agent-server.interface'
import { ServiceResponse } from '@/response/response.interface'
import { HttpStatusCode } from '@/response/status-code.enum'

@Injectable()
export class AgentServerService implements IAgentServerService {
  constructor(
    @Inject('IAgentServerService')
    private readonly httpService: IAgentServerService
  ) {}

  async listStaffs(): Promise<ServiceResponse<StaffsType[]>> {
    return this.httpService.listStaffs()
  }

  async getStaffProfile(
    staff_id: string
  ): Promise<ServiceResponse<StaffProfile>> {
    if (!staff_id) {
      return {
        code: HttpStatusCode.BAD_REQUEST,
        msg: 'staff_id不能为空',
        data: null
      }
    }
    return this.httpService.getStaffProfile(staff_id)
  }

  async getUserProfile(user_id: string): Promise<ServiceResponse<UserProfile>> {
    if (!user_id) {
      return {
        code: HttpStatusCode.BAD_REQUEST,
        msg: 'user_id不能为空',
        data: null
      }
    }
    return this.httpService.getUserProfile(user_id)
  }

  async listUsers(
    user_name: string,
    user_union_id: string
  ): Promise<ServiceResponse<UserProfile[]>> {
    if (!user_name && !user_union_id) {
      return {
        code: HttpStatusCode.BAD_REQUEST,
        msg: 'user_name和user_union_id不能同时为空',
        data: null
      }
    }
    return this.httpService.listUsers(user_name, user_union_id)
  }

  async getDialogueHistory(
    staff_id: string,
    user_id: string,
    recent_minutes: string
  ): Promise<ServiceResponse<DialogueHistory[]>> {
    if (!staff_id || !user_id) {
      return {
        code: HttpStatusCode.BAD_REQUEST,
        msg: 'staff_id和user_id不能为空',
        data: null
      }
    }
    return this.httpService.getDialogueHistory(
      staff_id,
      user_id,
      recent_minutes
    )
  }

  async listModels(): Promise<ServiceResponse<Model[]>> {
    return this.httpService.listModels()
  }

  async listScenes(): Promise<ServiceResponse<any[]>> {
    return this.httpService.listScenes()
  }

  async getBasePrompt(): Promise<ServiceResponse<string>> {
    return this.httpService.getBasePrompt()
  }

  async runPrompt(prompt: any): Promise<ServiceResponse<any>> {
    if (!prompt) {
      return {
        code: HttpStatusCode.BAD_REQUEST,
        msg: 'prompt不能为空',
        data: null
      }
    }
    return this.httpService.runPrompt(prompt)
  }
}
